@@ -206,9 +206,8 @@ class AccountFormGeneral(forms.ModelForm):
             account.role = self.cleaned_data["role"]
             if hasattr(account, "mailbox"):
                 # Update forward status according to account status
-                models.Alias.objects.filter(
-                    address=account.email, internal=False).update(
-                        enabled=account.is_active)
+                models.Alias.objects.filter(address=account.email).update(
+                    enabled=account.is_active)
         return account
 
 
@@ -421,10 +420,12 @@ class AccountFormMail(forms.Form, DynamicForm):
                     alias__address=alias).exists():
                 continue
             local_part, domname = split_mailbox(alias)
-            al = models.Alias(address=alias, enabled=account.is_active)
-            al.domain = models.Domain.objects.get(name=domname)
-            al.save()
-            al.set_recipients([self.mb.full_address])
+            al, _ = models.Alias.objects.get_or_create(
+                address=alias,
+                domain=models.Domain.objects.get(name=domname),
+                defaults={'enabled': account.is_active},
+            )
+            al.add_recipients([self.mb.full_address])
             al.post_create(user)
 
     def _update_sender_addresses(self):
