@@ -23,7 +23,7 @@ from . import mixins
 class Domain(mixins.MessageLimitMixin, AdminObject):
     """Mail domain."""
 
-    name = models.CharField(ugettext_lazy("name"), max_length=100, unique=True,
+    name = models.CharField(ugettext_lazy("name"), max_length=253, unique=True,
                             help_text=ugettext_lazy("The domain name"))
     quota = models.PositiveIntegerField(
         default=0,
@@ -80,15 +80,15 @@ class Domain(mixins.MessageLimitMixin, AdminObject):
         self.old_dkim_key_length = self.dkim_key_length
 
     @property
-    def domainalias_count(self):
+    def domainalias_count(self) -> int:
         return self.domainalias_set.count()
 
     @property
-    def mailbox_count(self):
+    def mailbox_count(self) -> int:
         return self.mailbox_set.count()
 
     @property
-    def mbalias_count(self):
+    def mbalias_count(self) -> int:
         return self.alias_set.filter(internal=False).count()
 
     @property
@@ -149,6 +149,35 @@ class Domain(mixins.MessageLimitMixin, AdminObject):
             return True
         return False
 
+    @property
+    def dns_global_status(self) -> str:
+        """Return global DNS status."""
+        if not self.enable_dns_checks or self.uses_a_reserved_tld:
+            return "disabled"
+        elif self.awaiting_checks():
+            return "pending"
+        config = dict(param_tools.get_global_parameters("admin"))
+        errors = []
+        if config["enable_mx_checks"] and not self.mxrecord_set.has_valids():
+            errors.append("mx")
+        if config["enable_dnsbl_checks"] and self.dnsblresult_set.blacklisted().exists():
+            errors.append("dnsbl")
+        if config["enable_spf_checks"]:
+            if self.spf_record is None or not self.spf_record.is_valid:
+                errors.append("spf")
+            if self.dkim_record is None or not self.dkim_record.is_valid:
+                errors.append("dkim")
+            if self.dmarc_record is None or not self.dmarc_record.is_valid:
+                errors.append("dmarc")
+        if config["enable_autoconfig_checks"]:
+            if self.autoconfig_record is None:
+                errors.append("autoconfig")
+            if self.autodiscover_record is None:
+                errors.append("autodiscover")
+        if len(errors) == 0:
+            return "ok"
+        return "critical"
+
     @cached_property
     def dnsbl_status_color(self):
         """Shortcut to DNSBL results."""
@@ -159,27 +188,27 @@ class Domain(mixins.MessageLimitMixin, AdminObject):
         else:
             return "success"
 
-    @cached_property
+    @property
     def spf_record(self):
         """Return SPF record."""
         return self.dnsrecord_set.filter(type="spf").first()
 
-    @cached_property
+    @property
     def dkim_record(self):
         """Return DKIM record."""
         return self.dnsrecord_set.filter(type="dkim").first()
 
-    @cached_property
+    @property
     def dmarc_record(self):
         """Return DMARC record."""
         return self.dnsrecord_set.filter(type="dmarc").first()
 
-    @cached_property
+    @property
     def autoconfig_record(self):
         """Return autoconfig record."""
         return self.dnsrecord_set.filter(type="autoconfig").first()
 
-    @cached_property
+    @property
     def autodiscover_record(self):
         """Return autodiscover record."""
         return self.dnsrecord_set.filter(type="autodiscover").first()
@@ -358,24 +387,32 @@ class Domain(mixins.MessageLimitMixin, AdminObject):
             instance=self)
         self.save(creator=user)
 
+    def to_csv_rows(self):
+        """Return a row to include in a CSV file."""
+        result = [
+            [
+                "domain",
+                force_text(self.name),
+                self.quota,
+                self.default_mailbox_quota,
+                self.enabled
+            ]
+        ]
+        for dalias in self.domainalias_set.all():
+            result.append(dalias.to_csv_row())
+        return result
+
     def to_csv(self, csvwriter):
         """Export domain and domain aliases to CSV format."""
-        csvwriter.writerow([
-            "domain",
-            force_text(self.name),
-            self.quota,
-            self.default_mailbox_quota,
-            self.enabled
-        ])
-        for dalias in self.domainalias_set.all():
-            dalias.to_csv(csvwriter)
+        for row in self.to_csv_rows():
+            csvwriter.writerow(row)
 
     def post_create(self, creator):
         """Post creation actions.
 
         :param ``User`` creator: user whos created this domain
         """
-        super(Domain, self).post_create(creator)
+        super().post_create(creator)
         for domalias in self.domainalias_set.all():
             domalias.post_create(creator)
 
