@@ -5,11 +5,13 @@ import shutil
 import tempfile
 from unittest import mock
 
+from dateutil.relativedelta import relativedelta
 import dns.resolver
 from testfixtures import compare
 
 from django.core.management import call_command
 from django.urls import reverse
+from django.utils import timezone
 from django.utils.html import escape
 
 from modoboa.core import factories as core_factories
@@ -203,7 +205,7 @@ class DomainTestCase(ModoTestCase):
         self.assertContains(response, "value=\"500\"")
         self.assertContains(response, "value=\"50\"")
 
-    @mock.patch.object(dns.resolver.Resolver, "query")
+    @mock.patch.object(dns.resolver.Resolver, "resolve")
     @mock.patch("socket.getaddrinfo")
     def test_create_and_check_mx(self, mock_getaddrinfo, mock_query):
         """Check for authorized MX record."""
@@ -342,9 +344,11 @@ class DomainTestCase(ModoTestCase):
         """Test logs list view."""
         domain = Domain.objects.get(name="test.com")
         ml_factories.MaillogFactory(from_domain=domain)
-        ml_factories.MaillogFactory(to_domain=domain, status="received")
-        ml_factories.MaillogFactory()
-        ml_factories.MaillogFactory()
+        ml_factories.MaillogFactory(
+            to_domain=domain, status="received",
+            date=timezone.now() + relativedelta(days=1))
+        ml_factories.MaillogFactory(date=timezone.now() + relativedelta(days=2))
+        ml_factories.MaillogFactory(date=timezone.now() + relativedelta(days=3))
         url = reverse("admin:domain_logs_list")
         response = self.ajax_get(url)
         self.assertIn("ID1", response["rows"])
@@ -399,7 +403,7 @@ class DKIMTestCase(ModoTestCase):
         factories.populate_database()
 
     def setUp(self):
-        super(DKIMTestCase, self).setUp()
+        super().setUp()
         self.workdir = tempfile.mkdtemp()
 
     def tearDown(self):
